@@ -1,3 +1,6 @@
+"""
+Custom callbacks used for training
+"""
 from pytorch_lightning import Callback, LightningModule, Trainer
 import os
 
@@ -12,9 +15,22 @@ class NeptuneModelLogger(Callback):
     """
 
     def __init__(self) -> None:
+        """
+        Base initialization, nothing specific needed here
+        """
         super().__init__()
 
     def on_validation_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        """
+        Save the best and last model checkpoints to Neptune after each validation
+
+        Args:
+            trainer: PyTorchLightning trainer
+            pl_module: LightningModule that is being trained
+
+        Returns:
+            None
+        """
         try:
             trainer.logger.experiment[0]["model_checkpoints/last.ckpt"].upload(
                 os.path.join(trainer.default_root_dir, "checkpoints", "last.ckpt")
@@ -26,6 +42,16 @@ class NeptuneModelLogger(Callback):
             pass
 
     def on_fit_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        """
+        Save out the best and last model checkpoints at the end of trainer.fit to Neptune
+
+        Args:
+            trainer: PyTorchLightning Trainer
+            pl_module: LightningModule being used for training
+
+        Returns:
+            None
+        """
         try:
             trainer.logger.experiment[0]["model_checkpoints/best.ckpt"].upload(
                 os.path.join(trainer.default_root_dir, "checkpoints", "best.ckpt"),
